"use strict";

var __spreadArrays = this && this.__spreadArrays || function () {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;

  for (var r = Array(s), k = 0, i = 0; i < il; i++) for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) r[k] = a[j];

  return r;
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyTo = void 0;

var types_1 = require("../../libs/types");

var ValueSchemaError_1 = require("../../libs/ValueSchemaError");

var BaseSchema_1 = require("../../schemaClasses/BaseSchema");
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */


function applyTo(values, options, keyStack) {
  var each = normalizeOptions(options.each);

  if (each === undefined) {
    return false;
  } // istanbul ignore next


  if (!types_1.isArray(values.output)) {
    return false;
  }

  var adjustedValues = [];

  for (var idx = 0; idx < values.output.length; idx++) {
    var element = values.output[idx]; // A trick in order to call _applyTo() private method from the outside (like "friend")

    try {
      var adjustedValue = each.schema["_applyTo"](element, function (err) {
        if (each.ignoresErrors) {
          throw Error("!IGNORE!");
        }

        return ValueSchemaError_1.ValueSchemaError.raise(err.cause, values, err.keyStack);
      }, __spreadArrays(keyStack, [idx]));
      adjustedValues.push(adjustedValue);
    } catch (err) {
      if (err.message === "!IGNORE!") {
        // ignore
        continue;
      }

      throw err;
    }
  } // replace with adjusted values


  values.output = adjustedValues;
  return false;
}

exports.applyTo = applyTo;
/**
 * normalize options
 * @param each each
 * @returns normalized options
 */

function normalizeOptions(each) {
  if (each === undefined) {
    return;
  }

  if (each instanceof BaseSchema_1.BaseSchema) {
    return {
      schema: each,
      ignoresErrors: false
    };
  }

  return each;
}