"use strict";

var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyTo = void 0;

var types_1 = require("../../libs/types");

var ValueSchemaError_1 = require("../../libs/ValueSchemaError");
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */


function applyTo(values, options, keyStack) {
  var minValue = normalizeOptions(options.minValue); // istanbul ignore next

  if (!types_1.isNumber(values.output)) {
    return false;
  }

  if (values.output >= minValue.value) {
    return false;
  }

  if (minValue.adjusts) {
    values.output = minValue.value;
    return false;
  }

  return ValueSchemaError_1.ValueSchemaError.raise(ValueSchemaError_1.CAUSE.MIN_VALUE, values, keyStack);
}

exports.applyTo = applyTo;
/**
 * normalize options
 * @param minValue options
 * @returns normalized options
 */

function normalizeOptions(minValue) {
  var defaultOptions = {
    value: Number.MIN_SAFE_INTEGER,
    adjusts: false
  };

  if (minValue === undefined) {
    return defaultOptions;
  }

  if (types_1.isNumber(minValue)) {
    return __assign(__assign({}, defaultOptions), {
      value: minValue
    });
  }

  return __assign(__assign({}, defaultOptions), minValue);
}