import { isNumber, isString } from "../../libs/types.mjs";
import { CAUSE, ValueSchemaError } from "../../libs/ValueSchemaError.mjs";
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */

export function applyTo(values, options, keyStack) {
  const maxLength = normalizeOptions(options.maxLength); // istanbul ignore next

  if (!isString(values.output)) {
    return false;
  }

  if (values.output.length <= maxLength.length) {
    return false;
  }

  if (maxLength.trims !== undefined && maxLength.trims) {
    values.output = values.output.substr(0, maxLength.length);
    return false;
  }

  return ValueSchemaError.raise(CAUSE.MAX_LENGTH, values, keyStack);
}
/**
 * normalize options
 * @param maxLength options
 * @returns normalized options
 */

function normalizeOptions(maxLength) {
  const defaultOptions = {
    length: Number.MAX_SAFE_INTEGER,
    trims: false
  };

  if (maxLength === undefined) {
    return defaultOptions;
  }

  if (isNumber(maxLength)) {
    return { ...defaultOptions,
      length: maxLength
    };
  }

  return { ...defaultOptions,
    ...maxLength
  };
}