"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyTo = exports.PATTERN = void 0;

var types_1 = require("../../libs/types");

var ValueSchemaError_1 = require("../../libs/ValueSchemaError");

var email_1 = require("../../libs/regexp/email");

var ipv4_1 = require("../../libs/regexp/ipv4");

var ipv6_1 = require("../../libs/regexp/ipv6");

var uri_1 = require("../../libs/regexp/uri");

exports.PATTERN = {
  EMAIL: email_1.REGEXP_EMAIL,
  HTTP: uri_1.REGEXP_HTTP,
  IPV4: ipv4_1.REGEXP_IPV4,
  IPV6: ipv6_1.REGEXP_IPV6,
  URI: uri_1.REGEXP_URI
};
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */

function applyTo(values, options, keyStack) {
  if (options.pattern === undefined) {
    return false;
  } // istanbul ignore next


  if (!types_1.isString(values.output)) {
    return false;
  }

  if (options.pattern.test(values.output)) {
    return false;
  }

  return ValueSchemaError_1.ValueSchemaError.raise(ValueSchemaError_1.CAUSE.PATTERN, values, keyStack);
}

exports.applyTo = applyTo;