import { isString } from "../../libs/types.mjs";
import { CAUSE, ValueSchemaError } from "../../libs/ValueSchemaError.mjs";
import { REGEXP_EMAIL } from "../../libs/regexp/email.mjs";
import { REGEXP_IPV4 } from "../../libs/regexp/ipv4.mjs";
import { REGEXP_IPV6 } from "../../libs/regexp/ipv6.mjs";
import { REGEXP_HTTP, REGEXP_URI } from "../../libs/regexp/uri.mjs";
export const PATTERN = {
  EMAIL: REGEXP_EMAIL,
  HTTP: REGEXP_HTTP,
  IPV4: REGEXP_IPV4,
  IPV6: REGEXP_IPV6,
  URI: REGEXP_URI
};
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */

export function applyTo(values, options, keyStack) {
  if (options.pattern === undefined) {
    return false;
  } // istanbul ignore next


  if (!isString(values.output)) {
    return false;
  }

  if (options.pattern.test(values.output)) {
    return false;
  }

  return ValueSchemaError.raise(CAUSE.PATTERN, values, keyStack);
}