import { isScalar, isString } from "../../libs/types.mjs";
import { CAUSE, ValueSchemaError } from "../../libs/ValueSchemaError.mjs";
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */

export function applyTo(values, options, keyStack) {
  const normalizedOptions = {
    strictType: false,
    ...options
  };

  if (isString(values.output)) {
    return false;
  } // strict type check


  if (normalizedOptions.strictType) {
    ValueSchemaError.raise(CAUSE.TYPE, values, keyStack);
  } // non-scalar value cannot be converted to string


  if (!isScalar(values.output)) {
    ValueSchemaError.raise(CAUSE.TYPE, values, keyStack);
  }

  values.output = String(values.output);
  return false;
}