"use strict";

var __spreadArrays = this && this.__spreadArrays || function () {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;

  for (var r = Array(s), k = 0, i = 0; i < il; i++) for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) r[k] = a[j];

  return r;
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applySchemaObjectCore = void 0;

var types_1 = require("./types");

var ValueSchemaError_1 = require("./ValueSchemaError");
/**
 * apply schema object to data
 * @param schemaObject schema object
 * @param data data to apply
 * @param onError error handler
 * @param onFinished finish handler
 * @param keyStack path to key that caused error
 * @returns applied data
 */


function applySchemaObjectCore(schemaObject, data, onError, onFinished, keyStack) {
  if (!types_1.isObject(data)) {
    var err = new ValueSchemaError_1.ValueSchemaError(ValueSchemaError_1.CAUSE.TYPE, data, keyStack);
    var result = onError(err);

    if (!types_1.isObject(result)) {
      throw err;
    }

    return result;
  }

  var appliedObject = {};
  var hasError = false;

  for (var _i = 0, _a = Object.keys(schemaObject); _i < _a.length; _i++) {
    var key = _a[_i]; // A trick in order to call _applyTo() private method from the outside (like "friend")

    appliedObject[key] = schemaObject[key]["_applyTo"](data[key], errorHandler, __spreadArrays(keyStack, [key]));
  }

  if (hasError) {
    onFinished();
  }

  return appliedObject;
  /**
   * error handler (to avoid "no-loop-func" error on eslint)
   * @param err error object
   * @returns error handler
   */

  function errorHandler(err) {
    hasError = true;
    return onError(err);
  }
}

exports.applySchemaObjectCore = applySchemaObjectCore;