"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.REGEXP_HTTP = exports.PATTERN_HTTP = exports.REGEXP_URI = exports.PATTERN_URI = void 0; // URI pattern follows RFC3986: https://tools.ietf.org/html/rfc3986

var rfc_1 = require("./rfc");

var ipv4_1 = require("./ipv4");

var ipv6_1 = require("./ipv6"); // Percent-Encoding: https://tools.ietf.org/html/rfc3986#section-2.1


var PCT_ENCODED = "%" + rfc_1.HEXDIG + rfc_1.HEXDIG; // Reserved Characters: https://tools.ietf.org/html/rfc3986#section-2.2
// const GEN_DELIMS = `[:/?#\\[]@]`;

var SUB_DELIMS = "[!$&'()*+,;=]"; // const RESERVED = `(${GEN_DELIMS}|${SUB_DELIMS})`;
// Unreserved Characters: https://tools.ietf.org/html/rfc3986#section-2.3

var UNRESERVED = "(" + rfc_1.ALPHA + "|" + rfc_1.DIGIT + "|[-._~])"; // Scheme: https://tools.ietf.org/html/rfc3986#section-3.1

var SCHEME = rfc_1.ALPHA + "(" + rfc_1.ALPHA + "|" + rfc_1.DIGIT + "|[+\\-.])*"; // User Information: https://tools.ietf.org/html/rfc3986#section-3.2.1

var USERINFO = "(" + UNRESERVED + "|" + PCT_ENCODED + "|" + SUB_DELIMS + "|:)*"; // Host: https://tools.ietf.org/html/rfc3986#section-3.2.2

var IPVFUTURE = "v" + rfc_1.HEXDIG + "+\\.(" + UNRESERVED + "|" + SUB_DELIMS + "|:)+";
var IP_LITERAL = "\\[(" + ipv6_1.PATTERN_IPV6 + "|" + IPVFUTURE + ")]";
var REG_NAME = "(" + UNRESERVED + "|" + PCT_ENCODED + "|" + SUB_DELIMS + ")*";
var HOST = "(" + IP_LITERAL + "|" + ipv4_1.PATTERN_IPV4 + "|" + REG_NAME + ")"; // Port: https://tools.ietf.org/html/rfc3986#section-3.2.3

var PORT = "\\d*"; // Authority: https://tools.ietf.org/html/rfc3986#section-3.2

var AUTHORITY = "(" + USERINFO + "@)?" + HOST + "(:" + PORT + ")?"; // Path: https://tools.ietf.org/html/rfc3986#section-3.3

var PCHAR = "(" + UNRESERVED + "|" + PCT_ENCODED + "|" + SUB_DELIMS + "|[:@])";
var SEGMENT = "(" + PCHAR + ")*";
var SEGMENT_NZ = "(" + PCHAR + ")+"; // const SEGMENT_NZ_NC = `(${UNRESERVED}|${PCT_ENCODED}|${SUB_DELIMS}|@)+`; // non-zero-length segment without any colon ":"

var PATH_EMPTY = ""; // zero characters

var PATH_ROOTLESS = SEGMENT_NZ + "(/" + SEGMENT + ")*"; // begins with a segment
// const PATH_NOSCHEME = `${SEGMENT_NZ_NC}(/${SEGMENT})*`; // begins with a non-colon segment

var PATH_ABSOLUTE = "/(" + SEGMENT_NZ + "(/" + SEGMENT + ")*)?"; // begins with "/" but not "//"

var PATH_ABEMPTY = "(/" + SEGMENT + ")*"; // begins with "/" or is empty
// const PATH = `(${PATH_ABEMPTY}|${PATH_ABSOLUTE}|${PATH_NOSCHEME}|${PATH_ROOTLESS}|${PATH_EMPTY})`;
// Query: https://tools.ietf.org/html/rfc3986#section-3.4

var QUERY = "(" + PCHAR + "|[/?])*"; // Fragment: https://tools.ietf.org/html/rfc3986#section-3.5

var FRAGMENT = "(" + PCHAR + "|[/?])*"; // Syntax Components: https://tools.ietf.org/html/rfc3986#section-3

var HIER_PART = "(//" + AUTHORITY + PATH_ABEMPTY + "|" + PATH_ABSOLUTE + "|" + PATH_ROOTLESS + "|" + PATH_EMPTY + ")";
var URI = SCHEME + ":" + HIER_PART + "(\\?" + QUERY + ")?(#" + FRAGMENT + ")?";
exports.PATTERN_URI = URI;
exports.REGEXP_URI = new RegExp("^" + exports.PATTERN_URI + "$", "i"); // pattern for HTTP

var HTTP = "https?://" + AUTHORITY + PATH_ABEMPTY + "(\\?" + QUERY + ")?(#" + FRAGMENT + ")?";
exports.PATTERN_HTTP = HTTP;
exports.REGEXP_HTTP = new RegExp("^" + exports.PATTERN_HTTP + "$", "i");