import { BaseSchema } from "../schemaClasses/BaseSchema";
import { ArraySchema } from "../schemaClasses/ArraySchema";
import { ObjectSchema } from "../schemaClasses/ObjectSchema";
export declare type ObjectTypeOf<S extends SchemaObject> = {
    [K in keyof S]: S[K] extends ArraySchema<infer T> ? T[] : S[K] extends ArraySchema<infer T, null> ? T[] | null : S[K] extends ObjectSchema<infer S2> ? ObjectTypeOf<S2> : S[K] extends ObjectSchema<infer S2, null> ? ObjectTypeOf<S2> | null : S[K] extends BaseSchema<boolean> ? boolean : S[K] extends BaseSchema<boolean | null> ? boolean | null : S[K] extends BaseSchema<number> ? number : S[K] extends BaseSchema<number | null> ? number | null : S[K] extends BaseSchema<string> ? string : S[K] extends BaseSchema<string | null> ? string | null : never;
};
declare type Scalar = boolean | number | string;
export declare type AnyObject = Record<string, unknown>;
export declare type SchemaObject = Record<string, BaseSchema>;
export declare type Key = string | number;
export interface Values<T = unknown> {
    input: unknown;
    output: T;
}
/**
 * make input/output values pair
 * @param value input value
 * @returns pairs
 */
export declare function makeValues(value: unknown): Values;
/**
 * check whether given value is a scalar or not
 * @param value value to check
 * @returns Yes/No
 */
export declare function isScalar(value: unknown): value is Scalar;
/**
 * check whether given value is a boolean or not
 * @param value value to check
 * @returns Yes/No
 */
export declare function isBoolean(value: unknown): value is boolean;
/**
 * check whether given value is a number or not
 * @param value value to check
 * @returns Yes/No
 */
export declare function isNumber(value: unknown): value is number;
/**
 * check whether given value is an integer or not
 * @param value value to check
 * @returns Yes/No
 */
export declare function isInteger(value: number): value is number;
/**
 * check whether given value is a string or not
 * @param value value to check
 * @returns Yes/No
 */
export declare function isString(value: unknown): value is string;
/**
 * check whether given value is an array or not
 * @param value value to check
 * @returns yes/no
 */
export declare function isArray(value: unknown): value is unknown[];
/**
 * check whether given value is an object or not
 * @param value value to check
 * @returns Yes/No
 */
export declare function isObject(value: unknown): value is AnyObject;
export {};
