import { Key, Values } from "../libs/types";
import { ValueSchemaError } from "../libs/ValueSchemaError";
export declare type ErrorHandler<T = unknown> = (err: ValueSchemaError) => T | never;
export declare type FinishHandler = () => void;
interface Options {
}
declare type ApplyTo<T> = (values: Values, options: Options, keyStack: Key[]) => values is Values<T>;
export declare type NullableOptions = {
    ifNull: null;
} | {
    ifUndefined: null;
} | {
    ifEmptyString: null;
};
/**
 * Base Schema Class
 */
export declare class BaseSchema<T = unknown> {
    private readonly options;
    private readonly applyToList;
    /**
     * constructor
     * @param options options
     * @param applyToList list of applyTo
     */
    constructor(options: Options, applyToList: ApplyTo<T>[]);
    /**
     * apply schema
     * @param value value to apply
     * @param onError error handler
     * @returns applied value
     */
    applyTo(value: unknown, onError?: ErrorHandler<T>): T;
    private _applyTo;
}
/**
 * default error handler
 * @param err error object
 */
export declare function onErrorDefault(err: ValueSchemaError): never;
/**
 * default finish handler
 */
export declare function onFinishedDefault(): void;
export {};
