"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onFinishedDefault = exports.onErrorDefault = exports.BaseSchema = void 0;

var types_1 = require("../libs/types");
/**
 * Base Schema Class
 */


var BaseSchema =
/** @class */
function () {
  /**
   * constructor
   * @param options options
   * @param applyToList list of applyTo
   */
  function BaseSchema(options, applyToList) {
    this.options = options;
    this.applyToList = applyToList;
  }
  /**
   * apply schema
   * @param value value to apply
   * @param onError error handler
   * @returns applied value
   */


  BaseSchema.prototype.applyTo = function (value, onError) {
    if (onError === void 0) {
      onError = onErrorDefault;
    }

    return this._applyTo(value, onError, []);
  };

  BaseSchema.prototype._applyTo = function (value, onError, keyStack) {
    try {
      var values = types_1.makeValues(value);

      for (var _i = 0, _a = this.applyToList; _i < _a.length; _i++) {
        var applyTo = _a[_i];

        if (applyTo(values, this.options, keyStack)) {
          return values.output;
        }
      }

      return values.output;
    } catch (err) {
      return onError(err);
    }
  };

  return BaseSchema;
}();

exports.BaseSchema = BaseSchema;
/**
 * default error handler
 * @param err error object
 */

function onErrorDefault(err) {
  throw err;
}

exports.onErrorDefault = onErrorDefault;
/**
 * default finish handler
 */

function onFinishedDefault() {// do nothing
}

exports.onFinishedDefault = onFinishedDefault;